@@ -164,7 +164,7 @@ gtk_source_file_class_init (GtkSourceFileClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_LOCATION,
 					 g_param_spec_object ("location",
-							      _("Location"),
+							      "Location",
 							      "",
 							      G_TYPE_FILE,
 							      G_PARAM_READWRITE |
@@ -181,7 +181,7 @@ gtk_source_file_class_init (GtkSourceFileClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_ENCODING,
 					 g_param_spec_boxed ("encoding",
-							     _("Encoding"),
+							     "Encoding",
 							     "",
 							     GTK_SOURCE_TYPE_ENCODING,
 							     G_PARAM_READABLE |
@@ -197,7 +197,7 @@ gtk_source_file_class_init (GtkSourceFileClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_NEWLINE_TYPE,
 					 g_param_spec_enum ("newline-type",
-							    _("Newline type"),
+							    "Newline type",
 							    "",
 							    GTK_SOURCE_TYPE_NEWLINE_TYPE,
 							    GTK_SOURCE_NEWLINE_TYPE_LF,
@@ -214,7 +214,7 @@ gtk_source_file_class_init (GtkSourceFileClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_COMPRESSION_TYPE,
 					 g_param_spec_enum ("compression-type",
-							    _("Compression type"),
+							    "Compression type",
 							    "",
 							    GTK_SOURCE_TYPE_COMPRESSION_TYPE,
 							    GTK_SOURCE_COMPRESSION_TYPE_NONE,
