@@ -511,11 +511,8 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_VIEW,
 	                                 g_param_spec_object ("view",
-	                                                      _("View"),
-							      /* Translators: gutters can be used to display information
-							       * on the left or on the right of the text view. To draw the
-							       * line numbers for example. */
-	                                                      _("The gutters' GtkSourceView"),
+	                                                      "View",
+	                                                      "",
 	                                                      GTK_SOURCE_TYPE_VIEW,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
@@ -527,8 +524,8 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_WINDOW_TYPE,
 	                                 g_param_spec_enum ("window_type",
-	                                                    _("Window Type"),
-	                                                    _("The gutters' text window type"),
+	                                                    "Window Type",
+	                                                    "The gutters' text window type",
 	                                                    GTK_TYPE_TEXT_WINDOW_TYPE,
 	                                                    0,
 	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
@@ -544,8 +541,8 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_XPAD,
 	                                 g_param_spec_int ("xpad",
-	                                                   _("X Padding"),
-	                                                   _("The x-padding"),
+	                                                   "X Padding",
+	                                                   "The x-padding",
 	                                                   -1,
 	                                                   G_MAXINT,
 	                                                   0,
@@ -564,8 +561,8 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_YPAD,
 	                                 g_param_spec_int ("ypad",
-	                                                   _("Y Padding"),
-	                                                   _("The y-padding"),
+	                                                   "Y Padding",
+	                                                   "The y-padding",
 	                                                   -1,
 	                                                   G_MAXINT,
 	                                                   0,
@@ -1058,6 +1055,8 @@ draw_cells (GtkSourceGutter *gutter,
 	gint cur_line;
 	GtkTextIter selection_start;
 	GtkTextIter selection_end;
+	gint selection_start_line = 0;
+	gint selection_end_line = 0;
 	gboolean has_selection;
 	GtkTextIter start;
 	gint i;
@@ -1070,23 +1069,14 @@ draw_cells (GtkSourceGutter *gutter,
 
 	cur_line = gtk_text_iter_get_line (&insert_iter);
 
-	gtk_text_buffer_get_selection_bounds (buffer,
-	                                      &selection_start,
-	                                      &selection_end);
-
-	has_selection = !gtk_text_iter_equal (&selection_start, &selection_end);
+	has_selection = gtk_text_buffer_get_selection_bounds (buffer,
+	                                                      &selection_start,
+	                                                      &selection_end);
 
 	if (has_selection)
 	{
-		if (!gtk_text_iter_starts_line (&selection_start))
-		{
-			gtk_text_iter_set_line_offset (&selection_start, 0);
-		}
-
-		if (!gtk_text_iter_ends_line (&selection_end))
-		{
-			gtk_text_iter_forward_to_line_end (&selection_end);
-		}
+		selection_start_line = gtk_text_iter_get_line (&selection_start);
+		selection_end_line = gtk_text_iter_get_line (&selection_end);
 	}
 
 	start = info->start;
@@ -1135,7 +1125,7 @@ draw_cells (GtkSourceGutter *gutter,
 		}
 
 		if (has_selection &&
-		    gtk_text_iter_in_range (&start, &selection_start, &selection_end))
+		    selection_start_line <= line_to_paint && line_to_paint <= selection_end_line)
 		{
 			state |= GTK_SOURCE_GUTTER_RENDERER_STATE_SELECTED;
 		}
